manifestgen

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Overview

Package manifestgen provides an agent for generating Kubernetes manifests.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Install

func Install(ctx context.Context, s *mcp.Server, c *config.Config) error

Install registers the tool with the MCP server.

Types

type Agent

type Agent struct {
	// contains filtered or unexported fields
}

Agent handles manifest generation via ADK.

func NewAgent

func NewAgent(llm model.LLM, cfg *config.Config) (*Agent, error)

NewAgent creates a new Agent attached to a specific text generator model.

func (*Agent) Run added in v0.12.0

func (a *Agent) Run(ctx context.Context, prompt string, sessionID string) (string, error)

Run executes the agent using the ADK runner.

type FetchModelServerVersionsArgs added in v0.12.0

type FetchModelServerVersionsArgs struct {
	Model       string `json:"model" jsonschema:"The model for which to list model server versions. Required."`
	ModelServer string `json:"model_server" jsonschema:"The model server for which to list versions. Required."`
}

FetchModelServerVersionsArgs holds arguments for fetching GIQ model server versions.

type FetchProfilesArgs added in v0.12.0

type FetchProfilesArgs struct {
	Model              string "json:\"model,omitempty\" jsonschema:\"Optional. Filter profiles by model name, e.g. 'gemini-2.5-pro'.\""
	ModelServer        string "json:\"model_server,omitempty\" jsonschema:\"Optional. Filter profiles by model server, e.g. 'vllm'.\""
	ModelServerVersion string "json:\"model_server_version,omitempty\" jsonschema:\"Optional. Filter profiles by model server version.\""
}

FetchProfilesArgs holds arguments for fetching GIQ profiles.

Jump to